==> rgxgen-1.4-sources.jar: com/github/curiousoddman/rgxgen/visitors/NotMatchingCaseInsensitiveGenerationVisitor.java <==
package com.github.curiousoddman.rgxgen.visitors;

/* **************************************************************************
   Copyright 2019 Vladislavs Varslavans

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
/* **************************************************************************/

import com.github.curiousoddman.rgxgen.config.RgxGenProperties;
import com.github.curiousoddman.rgxgen.nodes.SymbolSet;

import java.util.Map;
import java.util.Random;

public class NotMatchingCaseInsensitiveGenerationVisitor extends NotMatchingGenerationVisitor {
    public NotMatchingCaseInsensitiveGenerationVisitor(Random random, Map<Integer, String> groupValues, RgxGenProperties properties) {
        super(random, groupValues, properties);
    }

    @Override
    public void visit(SymbolSet node) {
        visitSymbolSet(node, SymbolSet::getSymbolsCaseInsensitive);
    }

    @Override
    protected boolean equalsFinalSymbolRandomString(String s1, String s2) {
        return s1.equalsIgnoreCase(s2);
    }
}

==> rgxgen-2.0-sources.jar: com/github/curiousoddman/rgxgen/visitors/NotMatchingCaseInsensitiveGenerationVisitor.java <==
package com.github.curiousoddman.rgxgen.visitors;

/* **************************************************************************
   Copyright 2019 Vladislavs Varslavans

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
/* **************************************************************************/

import com.github.curiousoddman.rgxgen.config.RgxGenProperties;
import com.github.curiousoddman.rgxgen.nodes.SymbolSet;

import java.util.Map;
import java.util.Random;

public class NotMatchingCaseInsensitiveGenerationVisitor extends NotMatchingGenerationVisitor {
    public NotMatchingCaseInsensitiveGenerationVisitor(Random random, Map<Integer, String> groupValues, RgxGenProperties properties) {
        super(random, groupValues, properties);
    }

    @Override
    public void visit(SymbolSet node) {
        visitSymbolSet(node, SymbolSet::getCaseInsensitiveSymbolSetIndexer);
    }

    @Override
    protected boolean equalsFinalSymbolRandomString(String s1, String s2) {
        return s1.equalsIgnoreCase(s2);
    }
}
